@@ -6,12 +6,12 @@ Ctypes bindings for libxdo
 
 import ctypes
 from ctypes import (
-    POINTER, c_char_p, c_int, c_long, c_ulong, c_void_p)
+    POINTER, c_char_p, c_int, c_ulong, c_void_p)
 
 from ctypes.util import find_library
 
 libxdo = ctypes.CDLL(find_library("xdo"))
-libc = ctypes.CDLL(ctypes.util.find_library('libc'))
+libc = ctypes.CDLL(ctypes.util.find_library('c'))
 
 libc.free.argtypes = (c_void_p,)
 libc.free.restype = None
